@@ -42,6 +42,8 @@ from trexmodel.models.datastore.reward_models import CustomerPointReward,\
     CustomerStampReward, CustomerEntitledVoucher, RevertedCustomerPointReward,\
     RevertedCustomerStampReward, CustomerEntitledTierRewardSummary
 from trexmodel.models.datastore.prepaid_models import CustomerPrepaidReward
+from trexapi.libs.api_decorator import elapsed_time_trace
+from trexmodel.models.merchant_helpers import return_customer_details
 
 logger = logging.getLogger('api')
 
@@ -227,7 +229,7 @@ def create_customer(customer_data_in_json, request_headers):
         
         return create_api_message(status_code=StatusCode.BAD_REQUEST)
 
-
+'''
 def _return_customer_details(customer):
     customer_details_dict = customer.to_dict(
                                         date_format="%d-%m-%Y", 
@@ -278,11 +280,7 @@ def _return_customer_reward(customer):
     customer_tier_membership = _get_tier_membership(customer)
     if customer_tier_membership:
         customer_reward_dict['tier_membership']  = customer_tier_membership
-    '''
-    if 'entitled_voucher_summary' in customer_details_dict:
-        customer_details_dict['voucher_summary']            = customer.entitled_voucher_summary
-        del customer_details_dict['entitled_voucher_summary']
-    '''
+    
     return customer_reward_dict
 
 def _return_customer_minimum_details(customer):
@@ -317,6 +315,7 @@ def _return_customer_minimum_details(customer):
         del customer_details_dict['entitled_voucher_summary']
     
     return customer_details_dict
+'''
     
 @customer_api_bp.route('/reference-code/<ref_code>', methods=['GET'])
 @auth_token_required
@@ -338,7 +337,7 @@ def read_customer(request_headers, ref_code):
         
         if customer:
             with db_client.context():
-                customer_details_dict = _return_customer_details(customer)
+                customer_details_dict = return_customer_details(customer)
             
             customer_details_json =  jsonify(customer_details_dict)
             
@@ -356,7 +355,9 @@ def read_customer(request_headers, ref_code):
         return create_api_message(status_code=StatusCode.BAD_REQUEST)
 
 @customer_api_bp.route('/customer-key/<customer_key>/customer-reward', methods=['GET'])
-@user_auth_token_required
+@auth_token_required
+@device_is_activated
+@elapsed_time_trace(trace_key='read_customer_reward')
 def read_customer_reward(customer_key):
     
     logger.debug('customer_key=%s', customer_key)
@@ -463,7 +464,7 @@ def read_customer_by_customer_key(customer_key):
             customer = Customer.fetch(customer_key)
             
             if customer:
-                customer_details_dict = _return_customer_details(customer)
+                customer_details_dict = return_customer_details(customer)
             
         if customer_details_dict:
             return jsonify(customer_details_dict)
@@ -801,7 +802,7 @@ def register_user_as_customer(user_data_in_json, request_headers):
                 if created_customer:
                     
                     
-                    
+                    '''
                     response_data = {
                                     'customer_key'              : created_customer.key_in_str,
                                     'registered_datetime'       : created_customer.registered_datetime.strftime("%d-%m-%Y %H:%M:%S"),
@@ -813,6 +814,8 @@ def register_user_as_customer(user_data_in_json, request_headers):
                                     }
                     
                     response_data.update(user_details_dict(existing_user_acct))
+                    '''
+                    response_data = return_customer_details(created_customer)
                     
                     logger.debug('register_user_as_customer debug: response_data=%s', response_data)
                     
@@ -929,6 +932,175 @@ def search_customer(search_member_data_in_json, request_headers, limit):
         #return create_api_message(gettext('Invalid input'), status_code=StatusCode.BAD_REQUEST)
         #return create_api_message('Invalid input', status_code=StatusCode.BAD_REQUEST)
 
+@customer_api_bp.route('/search/customer/<limit>', methods=['POST'])
+@auth_token_required
+@device_is_activated
+@request_json
+@request_headers
+#@test_session_expired
+def search_customer_details_only(search_member_data_in_json, request_headers, limit):
+    
+    #search_member_data_in_json   = request.get_json()
+    search_customer_form         = CustomerSearchForm(ImmutableMultiDict(search_member_data_in_json))
+    
+    logger.debug('search_member_data_in_json=%s', search_member_data_in_json)
+    
+    db_client = create_db_client(caller_info="search_customer_details_only")
+    customer_list = []
+    
+    if search_customer_form.validate():
+        name                        = search_customer_form.name.data
+        mobile_phone                = search_customer_form.mobile_phone.data
+        email                       = search_customer_form.email.data
+        reference_code              = search_customer_form.reference_code.data
+        merchant_reference_code     = search_customer_form.merchant_reference_code.data
+        #customer_data               = search_customer_form.customer_data.data
+    
+        acct_id     = request_headers.get('x-acct-id')
+        
+        logger.debug('acct_id=%s', acct_id)
+        logger.debug('name=%s', name)
+        logger.debug('email=%s', email)
+        logger.debug('mobile_phone=%s', mobile_phone)
+        logger.debug('reference_code=%s', reference_code)
+        logger.debug('merchant_reference_code=%s', merchant_reference_code)
+        
+        limit_int = int(limit)
+        
+        with db_client.context():
+            merchant_acct   = MerchantAcct.fetch(acct_id)
+            (search_results, total_count, next_cursor)  = Customer.search_merchant_customer(merchant_acct, 
+                                                                                            name                    = name, 
+                                                                                            email                   = email, 
+                                                                                            mobile_phone            = mobile_phone, 
+                                                                                            reference_code          = reference_code,
+                                                                                            merchant_reference_code = merchant_reference_code,
+                                                                                            limit                   = limit_int,
+                                                                                            )
+            
+            logger.debug('total_count=%s', total_count)
+            logger.debug('next_cursor=%s', next_cursor)
+            
+            for c in search_results:
+                user_details = c.registered_user_acct
+                customer_details_dict = c.to_dict(
+                                            date_format="%d-%m-%Y", 
+                                            datetime_format="%d-%m-%Y %H:%M:%S",
+                                            excluded_dict_properties=[
+                                                'registered_merchant_acct', 'tier_membership', 'memberships_list',
+                                                'reward_summary', 'prepaid_summary',
+                                                'entitled_voucher_summary', 'entitled_birthday_reward_summary',
+                                                'entitled_membership_reward_summary', 'entitled_lucky_draw_ticket_summary',
+                                                'kpi_summary','device_details',
+                                                ],
+                                            )
+                customer_details_dict['customer_key']               = c.key_in_str
+                customer_details_dict['is_email_verified']          = user_details.is_email_verified
+                customer_details_dict['is_mobile_phone_verified']   = user_details.is_mobile_phone_verified
+                
+                logger.debug('customer_details_dict=%s', customer_details_dict)
+                
+                customer_list.append(customer_details_dict)
+    
+        #return create_api_message(status_code=customer_list.OK, customer_list=customer_list)
+        customer_details_list_json =  jsonify(customer_list)
+            
+            
+        logger.debug('customer_details_list_json=%s', customer_details_list_json)
+            
+        return customer_details_list_json
+    else:
+        error_message = search_customer_form.create_rest_return_error_message()
+        return create_api_message(error_message, status_code=StatusCode.BAD_REQUEST)
+
+@customer_api_bp.route('/search/customer-for-membership/<limit>', methods=['POST'])
+@auth_token_required
+@device_is_activated
+@request_json
+@request_headers
+#@test_session_expired
+def search_customer_for_membership(search_member_data_in_json, request_headers, limit):
+    
+    #search_member_data_in_json   = request.get_json()
+    search_customer_form         = CustomerSearchForm(ImmutableMultiDict(search_member_data_in_json))
+    
+    logger.debug('search_member_data_in_json=%s', search_member_data_in_json)
+    
+    db_client = create_db_client(caller_info="search_customer")
+    customer_list = []
+    
+    if search_customer_form.validate():
+        name                        = search_customer_form.name.data
+        mobile_phone                = search_customer_form.mobile_phone.data
+        email                       = search_customer_form.email.data
+        reference_code              = search_customer_form.reference_code.data
+        merchant_reference_code     = search_customer_form.merchant_reference_code.data
+        #customer_data               = search_customer_form.customer_data.data
+    
+        acct_id     = request_headers.get('x-acct-id')
+        
+        logger.debug('acct_id=%s', acct_id)
+        logger.debug('name=%s', name)
+        logger.debug('email=%s', email)
+        logger.debug('mobile_phone=%s', mobile_phone)
+        logger.debug('reference_code=%s', reference_code)
+        logger.debug('merchant_reference_code=%s', merchant_reference_code)
+        
+        limit_int = int(limit)
+        
+        with db_client.context():
+            merchant_acct   = MerchantAcct.fetch(acct_id)
+            (search_results, total_count, next_cursor)  = Customer.search_merchant_customer(merchant_acct, 
+                                                                                            name                    = name, 
+                                                                                            email                   = email, 
+                                                                                            mobile_phone            = mobile_phone, 
+                                                                                            reference_code          = reference_code,
+                                                                                            merchant_reference_code = merchant_reference_code,
+                                                                                            limit                   = limit_int,
+                                                                                            )
+            
+            logger.debug('total_count=%s', total_count)
+            logger.debug('next_cursor=%s', next_cursor)
+            
+            for c in search_results:
+                customer_details_dict = c.to_dict(
+                                            date_format="%d-%m-%Y", 
+                                            datetime_format="%d-%m-%Y %H:%M:%S",
+                                            excluded_dict_properties=[
+                                                'registered_merchant_acct', 'tier_membership', 'memberships_list',
+                                                'reward_summary', 'prepaid_summary',
+                                                'entitled_voucher_summary', 'entitled_birthday_reward_summary',
+                                                'entitled_membership_reward_summary', 'entitled_lucky_draw_ticket_summary',
+                                                'kpi_summary','device_details',
+                                                ],
+                                            )
+                customer_details_dict['customer_key']               = c.key_in_str
+                
+                logger.debug('customer_details_dict=%s', customer_details_dict)
+                
+                #if 'membership' in customer_data
+                customer_basic_memberships_list = _list_customer_basic_memberships(c)
+                if customer_basic_memberships_list:
+                    customer_details_dict['basic_memberships'] = customer_basic_memberships_list
+                
+                tier_membership_data = _get_tier_membership(c)
+                if tier_membership_data:
+                    customer_details_dict['tier_membership'] = tier_membership_data
+                
+                customer_list.append(customer_details_dict)
+    
+        #return create_api_message(status_code=customer_list.OK, customer_list=customer_list)
+        customer_details_list_json =  jsonify(customer_list)
+            
+            
+        logger.debug('customer_details_list_json=%s', customer_details_list_json)
+            
+        return customer_details_list_json
+    else:
+        error_message = search_customer_form.create_rest_return_error_message()
+        return create_api_message(error_message, status_code=StatusCode.BAD_REQUEST)
+
+
 
 def _list_customer_basic_memberships(customer):
     customer_membership_final_list = []
@@ -981,7 +1153,19 @@ def _get_tier_membership(customer):
         
         return membership_data
         
+@customer_api_bp.route('/customer-key/<customer_key>/customer-membership', methods=['GET'])
+@auth_token_required
+def read_customer_membership(customer_key):
+    db_client = create_db_client(caller_info="read_customer_membership")
     
+    with db_client.context():
+        customer        = Customer.fetch(customer_key)
+        customer_membershis_list = _list_customer_basic_memberships(customer)
+        tier_membership_data = _get_tier_membership(customer)
+        if tier_membership_data:
+            customer_membershis_list.append(tier_membership_data)
+
+    return jsonify(customer_membershis_list)  
 
 @customer_api_bp.route('/reference-code/<reference_code>/list-membership', methods=['GET'])
 @auth_token_required
