@@ -355,34 +355,21 @@ def version_sync():
         version =  {
                                
                                 'setting':[
-                                            '''
+                                            
                                             {
                                                 "table_name": "setting",
-                                                "version" : 6,
-                                                "script": "ALTER TABLE setting ADD COLUMN device_token TEXT DEFAULT '';"
+                                                "version" : 10,
+                                                "script": "ALTER TABLE setting ADD COLUMN gmt_hour TEXT DEFAULT 8;"
                                                 
                                                 
                                             },
                                             {
                                                 "table_name": "setting",
-                                                "version" : 6,
-                                                "script": "ALTER TABLE setting ADD COLUMN enable_lock_screen TEXT DEFAULT 'false';"
+                                                "version" : 8,
+                                                "script": "ALTER TABLE setting ADD COLUMN industry_type TEXT DEFAULT 'fb';"
                                                 
                                                 
-                                            },
-                                            {
-                                                "table_name": "setting",
-                                                "version" : 6,
-                                                "script": "ALTER TABLE setting ADD COLUMN lock_screen_code TEXT DEFAULT '';"
-                                                
-                                                
-                                            },
-                                            {
-                                                "table_name": "setting",
-                                                "version" : 6,
-                                                "script": 'ALTER TABLE setting ADD COLUMN lock_screen_length_in_second INTEGER DEFAULT 30;'
                                             }
-                                            '''
                                             
                                                
                                         ],
