@@ -20,7 +20,7 @@ from trexlib.utils.string_util import is_not_empty
 from flask.json import jsonify
 from trexapi import conf as api_conf
 from trexapi.decorators.api_decorators import auth_token_required,\
-    user_auth_token_required_pass_reference_code
+    user_auth_token_required_pass_reference_code, user_auth_token_required
 from trexmodel.models.datastore.loyalty_models import LoyaltyDeviceSetting
 from trexmodel.models.datastore.pos_models import POSSetting
 from trexapi.controllers.api_routes import APIBaseResource
@@ -98,32 +98,58 @@ def read_merchant_acct(merchant_acct_code, reference_code):
     
     if is_not_empty(merchant_acct_code):
         db_client = create_db_client(caller_info="read_merchant_acct")
+        try:
+            with db_client.context():
+                merchant_acct   = MerchantAcct.get_by_account_code(merchant_acct_code)
+                logger.debug('merchant_acct=%s', merchant_acct)
+                user_acct       = User.get_by_reference_code(reference_code)
+                logger.debug('user_acct=%s', user_acct)
+                #logger.debug('industry=%s', merchant_acct.industry)
+                merchant_info = merchant_helpers.construct_merchant_acct_info(merchant_acct, referrer_code = user_acct.referral_code) 
+                logger.debug('merchant_info.industry_type=%s', merchant_info.get('industry_type'))
+                
+                merchant_rating_result  = MerchantRatingResult.get_by_merchant_acct(merchant_acct)
+                
+                
+                if merchant_rating_result:
+                    logger.debug('rating_result=%s', merchant_rating_result.rating_result)
+                    merchant_info['rating_result'] = {
+                                                        'score'                 : merchant_rating_result.score,
+                                                        'total_rating_count'    : merchant_rating_result.score,
+                                                        'reviews_details'       : merchant_rating_result.rating_result,
+                                                    }
+                
+                    
+            #logger.debug('merchant_info=%s', merchant_info)
+                
+            return create_api_message(status_code=StatusCode.OK,
+                                                   **merchant_info
+                                                   )
+        except:
+            logger.error('Failed due to %s', get_tracelog())
+            return create_api_message("Failed to read merchant details", status_code=StatusCode.BAD_REQUEST)
+    else:
+        return create_api_message("Missing merchant account key", status_code=StatusCode.BAD_REQUEST)
+    
+@merchant_api_bp.route('/<merchant_acct_code>/minimum-details-for-system', methods=['GET'])
+def read_minimum_merchant_acct_for_system(merchant_acct_code):
+    
+    merchant_acct           = None
+    
+    logger.debug('merchant_acct_code=%s', merchant_acct_code)
+    
+    if is_not_empty(merchant_acct_code):
+        db_client = create_db_client(caller_info="read_minimum_merchant_acct_for_system")
         with db_client.context():
             merchant_acct   = MerchantAcct.get_by_account_code(merchant_acct_code)
-            user_acct       = User.get_by_reference_code(reference_code)
-            logger.debug('industry=%s', merchant_acct.industry)
-            merchant_info = merchant_helpers.construct_merchant_acct_info(merchant_acct, referrer_code = user_acct.referral_code) 
-            logger.debug('merchant_info.industry_type=%s', merchant_info.get('industry_type'))
-            
-            merchant_rating_result  = MerchantRatingResult.get_by_merchant_acct(merchant_acct)
-            
-            
-            if merchant_rating_result:
-                logger.debug('rating_result=%s', merchant_rating_result.rating_result)
-                merchant_info['rating_result'] = {
-                                                    'score'                 : merchant_rating_result.score,
-                                                    'total_rating_count'    : merchant_rating_result.score,
-                                                    'reviews_details'       : merchant_rating_result.rating_result,
-                                                }
-            
-                
-        #logger.debug('merchant_info=%s', merchant_info)
+            merchant_info = merchant_helpers.construct_merchant_acct_info(merchant_acct, read_minimum=True) 
             
         return create_api_message(status_code=StatusCode.OK,
                                                **merchant_info
                                                )
     else:
         return create_api_message("Missing merchant account key", status_code=StatusCode.BAD_REQUEST)
+        
     
 @merchant_api_bp.route('/<merchant_acct_code>/referred-code/<referrer_code>/read-details', methods=['GET'])
 @request_values
@@ -326,6 +352,7 @@ def read_joined_brand_details(merchant_acct_code, reference_code):
         return create_api_message(status_code=StatusCode.BAD_REQUEST)
     
 @merchant_api_bp.route('/<merchant_acct_code>/customer-details/reference-code/<reference_code>', methods=['GET'])
+@user_auth_token_required
 @elapsed_time_trace(trace_key='read_customer_details')
 def read_customer_details(merchant_acct_code, reference_code):
     
@@ -349,7 +376,8 @@ def read_customer_details(merchant_acct_code, reference_code):
                                                     excluded_dict_properties=[
                                                         'reward_summary', 'entitled_voucher_summary', 'prepaid_summary', 
                                                         'entitled_lucky_draw_ticket_summary', 'kpi_summary',
-                                                        'entitled_birthday_reward_summary'
+                                                        'entitled_birthday_reward_summary', 'registered_merchant_acct',
+                                                        'registered_user_acct','device_details',
                                                         ],
                                                     
                                                     )
@@ -357,6 +385,8 @@ def read_customer_details(merchant_acct_code, reference_code):
                     customer_details['is_email_verified']          = user_details.is_email_verified
                     customer_details['is_mobile_phone_verified']   = user_details.is_mobile_phone_verified
                     
+                    logger.debug('is_referred_by_friend=%s', customer_details['is_referred_by_friend'])
+                    
                     customer_basic_memberships_list = _list_customer_basic_memberships(customer)
                     if customer_basic_memberships_list:
                         customer_details['basic_memberships'] = customer_basic_memberships_list
@@ -418,20 +448,21 @@ def _get_tier_membership(customer):
             
     if is_not_empty(customer.tier_membership):
         merchant_tier_membership = customer.tier_membership_entity
-        customer_tier_membership = CustomerTierMembership.get_by_customer_and_merchant_tier_membership(customer, merchant_tier_membership)
-        
-        membership_data = {
-                        'key'                   : customer_tier_membership.merchant_tier_membership_key,
-                        'label'                 : merchant_tier_membership.label,
-                        'entitled_date'         : customer_tier_membership.entitled_date.strftime('%d-%m-%Y'),
-                        'expiry_date'           : customer_tier_membership.expiry_date.strftime('%d-%m-%Y'),
-                        'card_image'            : merchant_tier_membership.membership_card_image,
-                        'desc'                  : merchant_tier_membership.desc if is_not_empty(merchant_tier_membership.desc) else '',
-                        'terms_and_conditions'  : merchant_tier_membership.terms_and_conditions if is_not_empty(merchant_tier_membership.terms_and_conditions) else '',
-                        'is_tier'               : True,
-                        }
-        
-        return membership_data
+        if merchant_tier_membership:
+            customer_tier_membership = CustomerTierMembership.get_by_customer_and_merchant_tier_membership(customer, merchant_tier_membership)
+            if customer_tier_membership:
+                membership_data = {
+                                'key'                   : customer_tier_membership.merchant_tier_membership_key,
+                                'label'                 : merchant_tier_membership.label,
+                                'entitled_date'         : customer_tier_membership.entitled_date.strftime('%d-%m-%Y'),
+                                'expiry_date'           : customer_tier_membership.expiry_date.strftime('%d-%m-%Y'),
+                                'card_image'            : merchant_tier_membership.membership_card_image,
+                                'desc'                  : merchant_tier_membership.desc if is_not_empty(merchant_tier_membership.desc) else '',
+                                'terms_and_conditions'  : merchant_tier_membership.terms_and_conditions if is_not_empty(merchant_tier_membership.terms_and_conditions) else '',
+                                'is_tier'               : True,
+                                }
+                
+                return membership_data
 
 @merchant_api_bp.route('/<merchant_key>/customer-details/reference-code/<reference_code>', methods=['GET'])
 @elapsed_time_trace(trace_key='read_merchant_customer_details')
@@ -449,7 +480,14 @@ def read_merchant_customer_details(merchant_key, reference_code):
             if customer:
             
                 user_details = customer.registered_user_acct
-                customer_details_dict = customer.to_dict(date_format="%d-%m-%Y", datetime_format="%d-%m-%Y %H:%M:%S")
+                customer_details_dict = customer.to_dict(date_format="%d-%m-%Y", datetime_format="%d-%m-%Y %H:%M:%S",
+                                                         excluded_dict_properties=[
+                                                            'reward_summary', 'entitled_voucher_summary', 'prepaid_summary', 
+                                                            'entitled_lucky_draw_ticket_summary', 'kpi_summary',
+                                                            'entitled_birthday_reward_summary', 'registered_merchant_acct',
+                                                            'registered_user_acct','device_details',
+                                                            ],
+                                                         )
                 customer_details_dict['customer_key']               = customer.key_in_str
                 customer_details_dict['is_email_verified']          = user_details.is_email_verified
                 customer_details_dict['is_mobile_phone_verified']   = user_details.is_mobile_phone_verified
@@ -566,53 +604,62 @@ class AuthenticateAPIResource(APIBaseResource):
         output_json = {}
         
         if is_not_empty(acct_id) and is_not_empty(api_key):
-            db_client = create_db_client(caller_info="AuthenticateAPIResource.post")
-            with db_client.context():
-                merchant_acct = MerchantAcct.fetch(acct_id)
-            
-                if merchant_acct:
-                    if api_key == merchant_acct.api_key:
-                        merchant_user               = MerchantUser.get_by_username(username)
-                        
-                        is_authorized = self.is_outlet_authorized(merchant_user, outlet_key)
-                        logger.debug('outlet is_authorized=%s', is_authorized)
-                        
-                        if is_authorized:
-                            outlet = Outlet.fetch(outlet_key)
-                            (expiry_datetime, token)    = self.generate_token(acct_id, username, api_access=True)
-                            #session['auth_username']    = username
-                            #session['acct_id']          = acct_id
-                            
-                            logger.debug('token=%s', token)
-                            logger.debug('expiry_datetime=%s', expiry_datetime)
-                            logger.debug('auth_username=%s', username)
+            if is_not_empty(outlet_key):
+                db_client = create_db_client(caller_info="AuthenticateAPIResource.post")
+                with db_client.context():
+                    merchant_acct = MerchantAcct.fetch(acct_id)
                 
-                            output_json =  {
-                                            'auth_token'        : token,
-                                            'expires_in_seconds': int(api_conf.API_TOKEN_EXPIRY_LENGTH_IN_MINUTE) * 60,
-                                            #'granted_outlet'    : merchant_user.granted_outlet_details_list,
-                                            'username'          : merchant_user.username,
-                                            'name'              : merchant_user.name,
-                                            'is_admin'          : merchant_user.is_admin,
-                                            'outlet_name'       : outlet.name,
-                                            'granted_access'    : merchant_user.permission.get('granted_access'),
-                                            #'gravatar_url'      : merchant_user.gravatar_url,
-                                            }
-                
-                            logger.debug('output_json=%s', output_json)
+                    if merchant_acct:
+                        if api_key == merchant_acct.api_key:
+                            merchant_user               = MerchantUser.get_by_username(username)
                             
-                            is_authenticated = True
+                            is_authorized = self.is_outlet_authorized(merchant_user, outlet_key)
+                            logger.debug('outlet is_authorized=%s', is_authorized)
+                            
+                            if is_authorized:
+                                outlet = Outlet.fetch(outlet_key)
+                                (expiry_datetime, token)    = self.generate_token(acct_id, username, api_access=True)
+                                #session['auth_username']    = username
+                                #session['acct_id']          = acct_id
+                                
+                                logger.debug('token=%s', token)
+                                logger.debug('expiry_datetime=%s', expiry_datetime)
+                                logger.debug('auth_username=%s', username)
                     
-            if is_authenticated:
-                return output_json
-            elif is_authorized==False:
-                abort(400, msg=["User is not authorized due to outlet is not granted"])
+                                output_json =  {
+                                                'auth_token'        : token,
+                                                'expires_in_seconds': int(api_conf.API_TOKEN_EXPIRY_LENGTH_IN_MINUTE) * 60,
+                                                #'granted_outlet'    : merchant_user.granted_outlet_details_list,
+                                                'username'          : merchant_user.username,
+                                                'name'              : merchant_user.name,
+                                                'is_admin'          : merchant_user.is_admin,
+                                                'outlet_name'       : outlet.name,
+                                                'granted_access'    : merchant_user.permission.get('granted_access'),
+                                                #'gravatar_url'      : merchant_user.gravatar_url,
+                                                }
+                    
+                                logger.debug('output_json=%s', output_json)
+                                
+                                is_authenticated = True
+                    
+                if is_authenticated:
+                    return output_json
+                elif is_authorized==False:
+                    abort(400, msg=["User is not authorized due to outlet is not granted"])
+            else:
+                abort(400, msg=["Missing outlet key"])
+        else:
+            abort(400, msg=["Missing account id or api key"])
                     
         abort(400, msg=["Failed to authenticate"])
         
     
     def is_outlet_authorized(self, merchant_user, outlet_key):
-        return True    
+        
+        outlet_keys_list = merchant_user.granted_outlets_search_list
+        if outlet_key in outlet_keys_list:
+            return True
+        return False    
 
 class ProgramDeviceAuthenticate(AccountActivatedAPIResource):
     
