@@ -62,16 +62,16 @@ def post_sales_transaction(transaction_data_in_json, request_headers):
     if transaction_form.validate():
         logger.debug('reward transaction data is valid')
         
-        sales_amount        = float(transaction_form.sales_amount.data)
-        tax_amount          = transaction_form.tax_amount.data
-        invoice_id          = transaction_form.invoice_id.data
-        remarks             = transaction_form.remarks.data
-        promotion_code      = transaction_form.promotion_code.data
-        invoice_details     = transaction_data_in_json.get('invoice_details')
+        sales_amount                = float(transaction_form.sales_amount.data)
+        tax_amount                  = transaction_form.tax_amount.data
+        invoice_id                  = transaction_form.invoice_id.data
+        remarks                     = transaction_form.remarks.data
+        promotion_code              = transaction_form.promotion_code.data
+        invoice_details             = transaction_data_in_json.get('invoice_details')
+        transact_datetime_in_gmt    = transaction_form.transact_datetime.data
         
         transact_datetime   = None
         
-        
         if tax_amount is None:
             tax_amount = .0
         else:
@@ -83,6 +83,7 @@ def post_sales_transaction(transaction_data_in_json, request_headers):
         logger.debug('promotion_code=%s', promotion_code)
         logger.debug('remarks=%s', remarks)
         logger.debug('invoice_details=%s', invoice_details)
+        logger.debug('transact_datetime_in_gmt=%s', transact_datetime_in_gmt)
         
         db_client = create_db_client(caller_info="post_sales_transaction")
         
@@ -101,7 +102,6 @@ def post_sales_transaction(transaction_data_in_json, request_headers):
             transact_datetime_in_gmt    = transaction_form.transact_datetime.data
             merchant_username           = get_logged_in_api_username()
             
-            
             if merchant_username:
                 try:
                     with db_client.context():
@@ -117,7 +117,7 @@ def post_sales_transaction(transaction_data_in_json, request_headers):
                                 return create_api_message('Transact datetime cannot be future', status_code=StatusCode.BAD_REQUEST)
                         
                         
-                        
+                        logger.debug('transact_datetime=%s', transact_datetime)
                         transact_merchant_user = MerchantUser.get_by_username(merchant_username)
                         
                         sales_transaction = create_sales_transaction( 
@@ -201,9 +201,10 @@ def read_instant_reward_from_sales_transaction_get(transaction_id):
         logger.debug('Invalid transaction id')
         return create_api_message(gettext('Invalid reward code'), status_code=StatusCode.BAD_REQUEST)
 
-@sales_api_bp.route('/transaction/<encrypted_transaction_id>/read-instant-reward', methods=['GET'])
-#@user_auth_token_required
-def read_instant_reward_get(encrypted_transaction_id): 
+@sales_api_bp.route('/reference-code/<reference_code>/transaction/<encrypted_transaction_id>/read-instant-reward', methods=['GET'])
+@user_auth_token_required
+def read_instant_reward_get(reference_code, encrypted_transaction_id): 
+    #reference_code = request_headers.get('x-reference-code')
     logger.debug('encrypted_transaction_id=%s', encrypted_transaction_id)
     try:
         transaction_id    = decrypt(encrypted_transaction_id)
@@ -211,24 +212,29 @@ def read_instant_reward_get(encrypted_transaction_id):
         logger.debug('Failed to decrypt transaction id')
         return create_api_message(gettext('Invalid reward code'), status_code=StatusCode.BAD_REQUEST)    
         
-    db_client = create_db_client(caller_info="read_instant_reward_get")
-    
+    db_client   = create_db_client(caller_info="read_instant_reward_get")
+    is_customer = False
     with db_client.context():
         sales_transaction = SalesTransaction.get_by_transaction_id(transaction_id)
     
     if sales_transaction:
         with db_client.context():
-            merchant_acct = sales_transaction.transact_merchant_acct
-            
+            merchant_acct   = sales_transaction.transact_merchant_acct
+            transact_outle  = sales_transaction.transact_outlet_entity
+            customer        = Customer.get_by_reference_code(reference_code, merchant_acct)
+            if customer:
+                is_customer = True
         instant_reward = {
                         #"entitled_url"     : EARN_INSTANT_REWARD_URL.format(code=encrypted_transaction_id),
                         'transaction_id'    : transaction_id,
                         'transact_datetime' : sales_transaction.transact_datetime.strftime("%d-%m-%Y %H:%M:%S"),
                         'transact_amount'   : sales_transaction.transact_amount,
                         'used'              : sales_transaction.used,
+                        'is_customer'       : is_customer,
                         #'used'             : False,
                         'currency'          : merchant_acct.currency_code,
                         'locale'            : merchant_acct.locale,
+                        'outlet_info'       : transact_outle.to_brief_dict(),
                         
                         }
         logger.debug('instant_reward=%s', instant_reward)
@@ -262,8 +268,7 @@ def encrypt_instant_reward_code_get(transaction_id):
     
 @sales_api_bp.route('/reference-code/<reference_code>/transaction/<encrypted_transaction_id>/customer-earn-instant-reward', methods=['POST'])
 @user_auth_token_required
-@request_headers
-def customer_earn_instant_reward(request_headers, reference_code, encrypted_transaction_id): 
+def customer_earn_instant_reward(reference_code, encrypted_transaction_id): 
     
     db_client = create_db_client(caller_info="customer_earn_instant_reward")
         
@@ -280,9 +285,9 @@ def customer_earn_instant_reward(request_headers, reference_code, encrypted_tran
         
         if sales_transaction:
             
-            logger.info('sales_transaction is found')
-            is_used = sales_transaction.used 
-            is_used = False
+            is_used = sales_transaction.used
+            logger.info('sales_transaction(%s) is found, is_used=%s', transaction_id, is_used) 
+            
             if is_used:
                 with db_client.context():
                     customer_transaction = CustomerTransaction.get_by_transaction_id(transaction_id)
@@ -296,7 +301,7 @@ def customer_earn_instant_reward(request_headers, reference_code, encrypted_tran
                         customer = Customer.get_by_reference_code(reference_code, merchant_acct)
                         
                         customer_transaction = _customer_earn_instant_reward(customer, sales_transaction, reference_code, )
-                        '''
+                        
                         if customer is None:
                             logger.info('Customer is not found, thus going to create new customer account')
                             instant_reward_issued_outlet = sales_transaction.transact_outlet_entity
@@ -311,7 +316,7 @@ def customer_earn_instant_reward(request_headers, reference_code, encrypted_tran
                             
                             if customer_transaction:
                                 customer_transaction = customer_transaction.to_dict(date_format="%d-%m-%Y", datetime_format="%d-%m-%Y %H:%M:%S")
-                        '''
+                        
                     if customer_transaction:
                         return jsonify(customer_transaction)
                     else:
@@ -326,7 +331,7 @@ def customer_earn_instant_reward(request_headers, reference_code, encrypted_tran
     else:
         return create_api_message('Transaction id is empty', status_code=StatusCode.BAD_REQUEST)
             
-@model_transactional(desc="_customer_earn_instant_reward")
+#@model_transactional(desc="_customer_earn_instant_reward")
 def _customer_earn_instant_reward(customer, sales_transaction, reference_code):
     if customer is None:
         logger.info('Customer is not found, thus going to create new customer account')
@@ -335,7 +340,9 @@ def _customer_earn_instant_reward(customer, sales_transaction, reference_code):
         existing_user_acct = User.get_by_reference_code(reference_code)
         
         customer = Customer.create_from_user(instant_reward_issued_outlet, existing_user_acct)
-    
+    else:
+        logger.info('Customer is found, customer =%s', customer.name)
+        
     if customer:
         for_testing = False
         customer_transaction = give_reward_from_sales_transaction(customer, sales_transaction, for_testing=for_testing,)
@@ -346,3 +353,4 @@ def _customer_earn_instant_reward(customer, sales_transaction, reference_code):
         return customer_transaction
     else:
         return None
+
