@@ -35,6 +35,7 @@ from trexmodel.models.datastore.helper.reward_model_helpers import check_redeem_
 from flask_babel import gettext
 from trexlib.libs.flask_wtf.request_wrapper import request_json, request_headers,\
     request_values
+from trexmodel.models.datastore.customer_models import Customer
 
 logger = logging.getLogger('api')
 
@@ -166,6 +167,7 @@ def redeem_voucher(redeem_voucher_data_in_json, request_headers):
                     if customer is None:
                         customer = customer_voucher.entitled_customer_entity
                     else:
+                        #this is used to check every voucher must same customer
                         checking_customer = customer_voucher.entitled_customer_entity
                         if checking_customer.key_in_str!=customer.key_in_str:
                             return create_api_message(gettext('Voucher must from same customer'), status_code=StatusCode.BAD_REQUEST)
@@ -174,43 +176,17 @@ def redeem_voucher(redeem_voucher_data_in_json, request_headers):
             try:
                 with db_client.context():
                     check_redeem_voucher_is_valid(customer, customer_vouchers_list, redeem_datetime=redeem_datetime)
-            
+                
+                logger.info('after completed redeem voucher checking')
             except Exception as error:
                 logger.error('Failed due to %s', get_tracelog())
                 return create_api_message(str(error), status_code=StatusCode.BAD_REQUEST)
             
-            @model_transactional(desc='redeem_voucher')
-            def __start_transaction_for_redeem_voucher():
-                
-                customer_redemption = CustomerRedemption.create(customer, program_conf.REWARD_FORMAT_VOUCHER , 
-                                                          redeemed_outlet               = redeemed_by_outlet,
-                                                          redeemed_amount               = 1,            
-                                                          redeemed_voucher_keys_list    = to_redeem_voucher_keys_list, 
-                                                          redeemed_by                   = redeemed_by, 
-                                                          redeemed_datetime             = redeemed_datetime,
-                                                          invoice_id                    = invoice_id,
-                                                          remarks                       = remarks,
-                                                          )
-                
-                transaction_id = customer_redemption.transaction_id
-                
-                for voucher in customer_vouchers_list:
-                    voucher.redeem(redeemed_by=redeemed_by, 
-                                   redeemed_outlet=redeemed_by_outlet, 
-                                   redeemed_datetime=redeemed_datetime, 
-                                   transaction_id=transaction_id)
-                    
-                for customer_voucher in customer_vouchers_list:
-                    
-                    create_redeemed_customer_voucher_to_upstream_for_merchant(customer_voucher) 
-                
-                return customer_redemption
-            
             if to_redeem_voucher_keys_list:
                 with db_client.context():
                     if to_redeem_voucher_keys_list:
                         
-                        customer_redemption = __start_transaction_for_redeem_voucher()
+                        customer_redemption = __start_transaction_for_redeem_voucher(customer, redeemed_by_outlet, redeemed_by, redeemed_datetime, invoice_id, remarks, customer_vouchers_list, to_redeem_voucher_keys_list, )
                         
                         logger.debug('customer_redemption=%s', customer_redemption)
                         
@@ -230,6 +206,35 @@ def redeem_voucher(redeem_voucher_data_in_json, request_headers):
         error_message = redeem_voucher_form.create_rest_return_error_message()
             
         return create_api_message(error_message, status_code=StatusCode.BAD_REQUEST)
+
+@model_transactional(desc='redeem_voucher')
+def __start_transaction_for_redeem_voucher(customer, redeemed_by_outlet, redeemed_by, redeemed_datetime, invoice_id, remarks, customer_vouchers_list, to_redeem_voucher_keys_list, ):
+    
+    customer_redemption = CustomerRedemption.create(customer, program_conf.REWARD_FORMAT_VOUCHER , 
+                                              redeemed_outlet               = redeemed_by_outlet,
+                                              redeemed_amount               = 1,            
+                                              redeemed_voucher_keys_list    = to_redeem_voucher_keys_list, 
+                                              redeemed_by                   = redeemed_by, 
+                                              redeemed_datetime             = redeemed_datetime,
+                                              invoice_id                    = invoice_id,
+                                              remarks                       = remarks,
+                                              )
+    
+    transaction_id = customer_redemption.transaction_id
+    
+    logger.info('voucher redemption transaction_id=%s', transaction_id)
+    
+    for voucher in customer_vouchers_list:
+        voucher.redeem(redeemed_by=redeemed_by, 
+                       redeemed_outlet=redeemed_by_outlet, 
+                       redeemed_datetime=redeemed_datetime, 
+                       transaction_id=transaction_id)
+        
+    for customer_voucher in customer_vouchers_list:
+        
+        create_redeemed_customer_voucher_to_upstream_for_merchant(customer_voucher) 
+    
+    return customer_redemption
         
 @voucher_api_bp.route('/voucher/<redeem_code>/remove', methods=['DELETE'])
 @auth_token_required
@@ -335,9 +340,11 @@ def remove_user_voucher(request_headers, reference_code, redeem_code):
     logger.info('redeem_code=%s', redeem_code)
     
     if is_not_empty(redeem_code):
-        reference_code = request_headers.get('x-reference-code')
+        reference_code      = request_headers.get('x-reference-code')
+        
         logger.debug('reference_code=%s', reference_code)
         db_client = create_db_client(caller_info="remove_user_voucher")
+        
         with db_client.context():
             customer_voucher    = CustomerEntitledVoucher.get_by_redeem_code(redeem_code)
             
@@ -346,14 +353,17 @@ def remove_user_voucher(request_headers, reference_code, redeem_code):
                 customer_voucher.remove()  
                 customer = customer_voucher.entitled_customer_acct
                 customer.update_after_removed_voucher(customer_voucher)
+                return create_api_message(status_code=StatusCode.OK)
             else:
-                logger.info('voucher is not found')    
-               
-        if customer_voucher and customer_voucher.is_removed:        
+                merchant_acct_key = request_headers.get('x-acct-id')
+                if is_not_empty(merchant_acct_key):
+                    merchant_acct           = MerchantAcct.fetch(merchant_acct_key)
+                    if merchant_acct:
+                        customer = Customer.get_by_reference_code(reference_code, merchant_acct)
+                        if customer:
+                            customer.update_after_removed_voucher_by_redeem_code(redeem_code)
+                            
+                            return create_api_message(status_code=StatusCode.OK)
         
-            return create_api_message(status_code=StatusCode.OK)
-        else:
-            logger.info('Invalid voucher redeem code')
-            return create_api_message('Invalid voucher redeem code', status_code=StatusCode.BAD_REQUEST)
     else:
         return create_api_message('Missing voucher redeem code', status_code=StatusCode.BAD_REQUEST)
